@@ -34,10 +34,10 @@
 #include <item.h>
 #include <itemfetchscope.h>
 #include <kcontacts/addressee.h>
-#include <kcolorscheme.h>
-#include <kconfiggroup.h>
+#include <KColorScheme>
+#include <KConfigGroup>
 #include <KLocalizedString>
-#include <kstringhandler.h>
+#include <KStringHandler>
 
 #include <QVBoxLayout>
 #include <QIcon>
@@ -73,7 +73,7 @@ public:
         static QPixmap defaultMapPixmap = QIcon::fromTheme(QStringLiteral("map-symbolic")).pixmap(QSize(16, 16));
         static QPixmap defaultSmsPixmap = QIcon::fromTheme(KContacts::Impp::serviceIcon(QStringLiteral("sms"))).pixmap(QSize(16, 16));
 
-        mParent->setWindowTitle(i18n("Contact %1", mCurrentContact.assembledName()));
+        mParent->setWindowTitle(i18nc("@title:window", "Contact %1", mCurrentContact.assembledName()));
 
         if (mCurrentContact.photo().isIntern()) {
             mBrowser->document()->addResource(QTextDocument::ImageResource,
